.. figure :: images/kinto-logo.png
    :align: center

    **Kinto** — Store, Sync, Share, and Self-Host.

Kinto is a minimalist JSON storage service with synchronisation and sharing
abilities.

Table of content
================

.. toctree::
   :maxdepth: 1

   overview
   concepts
   community
   tutorials/index
   configuration/index
   api/index
   faq
   troubleshooting
   changelog
   core/reference/glossary
   core/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
